# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import maintenance_window_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2


class MaintenanceWindowStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.MaintenanceWindow/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.CreateMaintenanceWindowRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.MaintenanceWindow/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.UpdateMaintenanceWindowRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
                )
        self.close = channel.unary_unary(
                '/spaceone.api.monitoring.v1.MaintenanceWindow/close',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.MaintenanceWindow/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.GetMaintenanceWindowRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.MaintenanceWindow/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.MaintenanceWindow/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class MaintenanceWindowServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new MaintenanceWindow. When creating a MaintenanceWindow, you can set the title and maintenance schedule of the MaintenanceWindow. From the `start_time` to the `end_time` specified by the schedule set in this method, alerts in the Projects linked with the MaintenanceWindow are ceased.
        request_example: >-
        {
        "title": "The dev server is under regular maintenance.",
        "projects": ["project-123456789012"],
        "start_time": "2022-01-01T09:45:00.000Z",
        "end_time": "2022-01-01T10:45:00.000Z",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "title": "The dev server is under regular maintenance.",
        "state": "OPEN",
        "start_time": "2022-01-01T09:45:00.000Z",
        "end_time": "2022-01-01T10:45:00.000Z",
        "tags": {},
        "projects": [
        "project-123456789012"
        ],
        "domain_id": "domain-123456789012",
        "created_by": "user1@email.com",
        "created_at": "2022-06-02T09:46:49.196Z",
        "updated_at": "2022-06-02T09:46:49.196Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific MaintenanceWindow. You can make changes in MaintenanceWindow settings including, the `title` and the schedule.
        request_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "title": "The dev server is under regular maintenance.",
        "projects": ["project-123456789012"],
        "start_time": "2022-01-03T00:00:00.000Z",
        "end_time": "2022-01-03T01:00:00.000Z",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "title": "The dev server is under regular maintenance.",
        "state": "OPEN",
        "start_time": "2022-06-03T00:00:00.000Z",
        "end_time": "2022-06-03T01:00:00.000Z",
        "tags": {},
        "projects": [
        "project-123456789012"
        ],
        "domain_id": "domain-123456789012",
        "created_by": "user1@email.com",
        "created_at": "2022-01-02T09:46:49.196Z",
        "updated_at": "2022-01-02T09:46:49.196Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def close(self, request, context):
        """
        desc: Closes a MaintenanceWindow by changing the state of the MaintenanceWindow to `CLOSED` when the maintenance is completed. As the MaintenanceWindow is not deleted but closed, the maintenance history remains undeleted.
        request_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "title": "The dev server is under regular maintenance.",
        "state": "CLOSED",
        "start_time": "2022-06-03T00:00:00.000Z",
        "end_time": "2022-06-03T01:00:00.000Z",
        "tags": {},
        "projects": [
        "project-123456789012"
        ],
        "domain_id": "domain-123456789012",
        "created_by": "user1@email.com",
        "created_at": "2022-01-02T09:46:49.196Z",
        "updated_at": "2022-01-02T09:46:49.196Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific MaintenanceWindow. Prints detailed information about the MaintenanceWindow, including the title and the schedule.
        request_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "maintenance_window_id": "mw-123456789012",
        "title": "The dev server is under regular maintenance.",
        "state": "OPEN",
        "start_time": "2022-06-03T00:00:00.000Z",
        "end_time": "2022-06-03T01:00:00.000Z",
        "tags": {},
        "projects": [
        "project-123456789012"
        ],
        "domain_id": "domain-123456789012",
        "created_by": "user1@email.com",
        "created_at": "2022-01-02T09:46:49.196Z",
        "updated_at": "2022-01-02T09:46:49.196Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all MaintenanceWindows. You can use a query to get a filtered list of MaintenanceWindows.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "maintenance_window_id": "mw-123456789012",
        "title": "The dev server is under regular maintenance.",
        "state": "OPEN",
        "start_time": "2022-06-03T00:00:00.000Z",
        "end_time": "2022-06-03T01:00:00.000Z",
        "tags": {},
        "projects": [
        "project-123456789012"
        ],
        "domain_id": "domain-123456789012",
        "created_by": "user1@email.com",
        "created_at": "2022-01-01T09:59:01.966Z",
        "updated_at": "2022-01-01T09:59:01.966Z"
        },
        {
        "maintenance_window_id": "mw-987654321098",
        "title": "The prd server is under regular maintenance.",
        "state": "OPEN",
        "start_time": "2022-06-03T00:00:00.000Z",
        "end_time": "2022-06-03T01:00:00.000Z",
        "tags": {},
        "projects": [
        "project-123456789012"
        ],
        "domain_id": "domain-123456789012",
        "created_by": "user2@email.com",
        "created_at": "2022-01-02T09:57:28.999Z",
        "updated_at": "2022-01-02T09:57:28.999Z"
        }
        ],
        "total_count": 50
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MaintenanceWindowServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.CreateMaintenanceWindowRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.UpdateMaintenanceWindowRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.SerializeToString,
            ),
            'close': grpc.unary_unary_rpc_method_handler(
                    servicer.close,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.GetMaintenanceWindowRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.MaintenanceWindow', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MaintenanceWindow(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.MaintenanceWindow/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.CreateMaintenanceWindowRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.MaintenanceWindow/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.UpdateMaintenanceWindowRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def close(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.MaintenanceWindow/close',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.MaintenanceWindow/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.GetMaintenanceWindowRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.MaintenanceWindow/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.MaintenanceWindow/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_maintenance__window__pb2.MaintenanceWindowStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/right_size.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/inventory/v1/right_size.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"?\n\x13GetRightSizeRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x15\n\rright_size_id\x18\x02 \x01(\t\"O\n\x0eRightSizeQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"]\n\x12RightSizeStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xab\x01\n\x0fRightSizeDetail\x12\x15\n\rdefinition_id\x18\x01 \x01(\t\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x15\n\rsetting_value\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65tail_description\x18\x04 \x01(\t\x12\x39\n\x18metric_stat_result_value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdb\x03\n\rRightSizeInfo\x12\x15\n\rright_size_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x0c\n\x04\x66lag\x18\x06 \x01(\t\x12\x17\n\x0fright_size_type\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x15\n\rresource_name\x18\t \x01(\t\x12\x13\n\x0bresource_id\x18\n \x01(\t\x12\x33\n\x12\x63loud_service_info\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nsetting_id\x18\x0c \x01(\t\x12\x39\n\x18recommendation_cost_info\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x11right_size_detail\x18\x0e \x03(\x0b\x32*.spaceone.api.inventory.v1.RightSizeDetail\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\nupdated_at\x18\x10 \x01(\t\x12\x13\n\x0b\x61nalyzed_at\x18\x11 \x01(\t\"`\n\x0eRightSizesInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.inventory.v1.RightSizeInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x90\x03\n\tRightSize\x12\x85\x01\n\x03get\x12..spaceone.api.inventory.v1.GetRightSizeRequest\x1a(.spaceone.api.inventory.v1.RightSizeInfo\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/inventory/v1/right-size/get\x12\x83\x01\n\x04list\x12).spaceone.api.inventory.v1.RightSizeQuery\x1a).spaceone.api.inventory.v1.RightSizesInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/right-size/list\x12u\n\x04stat\x12-.spaceone.api.inventory.v1.RightSizeStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/right-size/statb\x06proto3')



_GETRIGHTSIZEREQUEST = DESCRIPTOR.message_types_by_name['GetRightSizeRequest']
_RIGHTSIZEQUERY = DESCRIPTOR.message_types_by_name['RightSizeQuery']
_RIGHTSIZESTATQUERY = DESCRIPTOR.message_types_by_name['RightSizeStatQuery']
_RIGHTSIZEDETAIL = DESCRIPTOR.message_types_by_name['RightSizeDetail']
_RIGHTSIZEINFO = DESCRIPTOR.message_types_by_name['RightSizeInfo']
_RIGHTSIZESINFO = DESCRIPTOR.message_types_by_name['RightSizesInfo']
GetRightSizeRequest = _reflection.GeneratedProtocolMessageType('GetRightSizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRIGHTSIZEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetRightSizeRequest)
  })
_sym_db.RegisterMessage(GetRightSizeRequest)

RightSizeQuery = _reflection.GeneratedProtocolMessageType('RightSizeQuery', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeQuery)
  })
_sym_db.RegisterMessage(RightSizeQuery)

RightSizeStatQuery = _reflection.GeneratedProtocolMessageType('RightSizeStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeStatQuery)
  })
_sym_db.RegisterMessage(RightSizeStatQuery)

RightSizeDetail = _reflection.GeneratedProtocolMessageType('RightSizeDetail', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZEDETAIL,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeDetail)
  })
_sym_db.RegisterMessage(RightSizeDetail)

RightSizeInfo = _reflection.GeneratedProtocolMessageType('RightSizeInfo', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZEINFO,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizeInfo)
  })
_sym_db.RegisterMessage(RightSizeInfo)

RightSizesInfo = _reflection.GeneratedProtocolMessageType('RightSizesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RIGHTSIZESINFO,
  '__module__' : 'spaceone.api.inventory.v1.right_size_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RightSizesInfo)
  })
_sym_db.RegisterMessage(RightSizesInfo)

_RIGHTSIZE = DESCRIPTOR.services_by_name['RightSize']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RIGHTSIZE.methods_by_name['get']._options = None
  _RIGHTSIZE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\036\"\034/inventory/v1/right-size/get'
  _RIGHTSIZE.methods_by_name['list']._options = None
  _RIGHTSIZE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/right-size/list'
  _RIGHTSIZE.methods_by_name['stat']._options = None
  _RIGHTSIZE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/right-size/stat'
  _GETRIGHTSIZEREQUEST._serialized_start=167
  _GETRIGHTSIZEREQUEST._serialized_end=230
  _RIGHTSIZEQUERY._serialized_start=232
  _RIGHTSIZEQUERY._serialized_end=311
  _RIGHTSIZESTATQUERY._serialized_start=313
  _RIGHTSIZESTATQUERY._serialized_end=406
  _RIGHTSIZEDETAIL._serialized_start=409
  _RIGHTSIZEDETAIL._serialized_end=580
  _RIGHTSIZEINFO._serialized_start=583
  _RIGHTSIZEINFO._serialized_end=1058
  _RIGHTSIZESINFO._serialized_start=1060
  _RIGHTSIZESINFO._serialized_end=1156
  _RIGHTSIZE._serialized_start=1159
  _RIGHTSIZE._serialized_end=1559
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import project_alert_config_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2


class ProjectAlertConfigStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.ProjectAlertConfig/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.CreateProjectAlertConfigRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.ProjectAlertConfig/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.UpdateProjectAlertConfigRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.monitoring.v1.ProjectAlertConfig/delete',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.ProjectAlertConfig/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.GetProjectAlertConfigRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.ProjectAlertConfig/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.ProjectAlertConfig/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class ProjectAlertConfigServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new ProjectAlertConfig in a specific Project. When creating a ProjectAlertConfig, validation of the Project is preceded. After the validation is done, ProjectAlertConfig enables EscalationPolicy to be set in the Project, or enables `enum` type `recovery_mode` and `notification_urgency` to be set through the `options` parameter.  The parameter `recovery_mode` is for changing the state of the Alert to `resolved` if the external monitoring solution sends the resolved Alert. The parameter `notification_urgency` is used to choose whether you will get all Alerts or only urgent ones.
        request_example: >-
        {
        "project_id": "project-dee2a81d4859",
        "escalation_policy_id": "ep-b441abe04ca9",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "AUTO"
        },
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "project_id": "project-dee2a81d4859",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "AUTO"
        },
        "escalation_policy_info": {
        "escalation_policy_id": "ep-b441abe04ca9",
        "name": "Global New Policy"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-27T05:12:22.998Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific ProjectAlertConfig. You can make changes in ProjectAlertConfig settings, including the EscalationPolicy to apply. You can also change `notification_urgency` and `recovery_mode` by modifying the `options` parameter.
        request_example: >-
        {
        "project_id": "project-dee2a81d4859",
        "escalation_policy_id": "ep-4ee42a9b2d96",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "MANUAL"
        },
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "project_id": "project-dee2a81d4859",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "MANUAL"
        },
        "escalation_policy_info": {
        "escalation_policy_id": "ep-4ee42a9b2d96",
        "name": "HAHA",
        "is_default": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-27T05:15:02.697Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific ProjectAlertConfig. Deletes alert configuration data in a Project.
        request_example: >-
        {
        "project_id": "project-dee2a81d4859",
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific ProjectAlertConfig. Prints detailed information about the ProjectAlertConfig, including EscalationPolicy, recovery mode, and notification urgency.
        request_example: >-
        {
        "project_id": "project-430bf6ab1e6d",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "project_id": "project-430bf6ab1e6d",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "AUTO"
        },
        "escalation_policy_info": {
        "escalation_policy_id": "ep-4ee42a9b2d96",
        "name": "HAHA",
        "is_default": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-03T08:17:11.715Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all ProjectAlertConfigs from all projects configured in the same domain. You can use a query to get a filtered list of ProjectAlertConfigs.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "results": [
        {
        "project_id": "project-18655561c535",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "MANUAL"
        },
        "escalation_policy_info": {
        "escalation_policy_id": "ep-4ee42a9b2d96",
        "name": "HAHA",
        "is_default": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-05-17T02:09:19.839Z"
        },
        {
        "project_id": "project-9074eea97d7e",
        "options": {
        "notification_urgency": "ALL",
        "recovery_mode": "MANUAL"
        },
        "escalation_policy_info": {
        "escalation_policy_id": "ep-b441abe04ca9",
        "name": "Global New Policy"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-24T02:50:50.535Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectAlertConfigServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.CreateProjectAlertConfigRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.UpdateProjectAlertConfigRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.GetProjectAlertConfigRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.ProjectAlertConfig', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectAlertConfig(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.ProjectAlertConfig/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.CreateProjectAlertConfigRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.ProjectAlertConfig/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.UpdateProjectAlertConfigRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.ProjectAlertConfig/delete',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.ProjectAlertConfig/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.GetProjectAlertConfigRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.ProjectAlertConfig/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.ProjectAlertConfig/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_project__alert__config__pb2.ProjectAlertConfigStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$spaceone/api/monitoring/v1/log.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\"\xaf\x01\n\nLogRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x0f\n\x07keyword\x18\x03 \x01(\t\x12\r\n\x05start\x18\n \x01(\t\x12\x0b\n\x03\x65nd\x18\x0b \x01(\t\x12%\n\x04sort\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05limit\x18\x10 \x01(\x05\x12\x11\n\tdomain_id\x18\x14 \x01(\t\"M\n\x0bLogDataInfo\x12+\n\x07results\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x99\x01\n\x03Log\x12\x91\x01\n\x04list\x12&.spaceone.api.monitoring.v1.LogRequest\x1a\'.spaceone.api.monitoring.v1.LogDataInfo\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/monitoring/v1/data-source/{data_source_id}/logsb\x06proto3')



_LOGREQUEST = DESCRIPTOR.message_types_by_name['LogRequest']
_LOGDATAINFO = DESCRIPTOR.message_types_by_name['LogDataInfo']
LogRequest = _reflection.GeneratedProtocolMessageType('LogRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.log_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.LogRequest)
  })
_sym_db.RegisterMessage(LogRequest)

LogDataInfo = _reflection.GeneratedProtocolMessageType('LogDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _LOGDATAINFO,
  '__module__' : 'spaceone.api.monitoring.v1.log_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.LogDataInfo)
  })
_sym_db.RegisterMessage(LogDataInfo)

_LOG = DESCRIPTOR.services_by_name['Log']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOG.methods_by_name['list']._options = None
  _LOG.methods_by_name['list']._serialized_options = b'\202\323\344\223\0022\0220/monitoring/v1/data-source/{data_source_id}/logs'
  _LOGREQUEST._serialized_start=129
  _LOGREQUEST._serialized_end=304
  _LOGDATAINFO._serialized_start=306
  _LOGDATAINFO._serialized_end=383
  _LOG._serialized_start=386
  _LOG._serialized_end=539
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/monitoring/v1/event.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"I\n\rEventResource\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"8\n\x0c\x45ventAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\"c\n\x12\x43reateEventRequest\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x12\n\naccess_key\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"D\n\x0fGetEventRequest\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x88\x02\n\nEventQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x11\n\tevent_key\x18\x03 \x01(\t\x12\x12\n\nevent_type\x18\x04 \x01(\t\x12\x10\n\x08severity\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x08 \x01(\t\x12\x10\n\x08\x61lert_id\x18\x0b \x01(\t\x12\x12\n\nwebhook_id\x18\x0c \x01(\t\x12\x12\n\nproject_id\x18\r \x01(\t\x12\x11\n\tdomain_id\x18\x0e \x01(\t\"\xf8\x03\n\tEventInfo\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\x12\x11\n\tevent_key\x18\x02 \x01(\t\x12\x12\n\nevent_type\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08severity\x18\x06 \x01(\t\x12\x0c\n\x04rule\x18\x07 \x01(\t\x12;\n\x08resource\x18\x08 \x01(\x0b\x32).spaceone.api.monitoring.v1.EventResource\x12\x10\n\x08provider\x18\t \x01(\t\x12\x39\n\x07\x61\x63\x63ount\x18\n \x01(\x0b\x32(.spaceone.api.monitoring.v1.EventAccount\x12\x11\n\timage_url\x18\x0b \x01(\t\x12)\n\x08raw_data\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x61\x64\x64itional_info\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08\x61lert_id\x18\x1f \x01(\t\x12\x12\n\nwebhook_id\x18  \x01(\t\x12\x12\n\nproject_id\x18! \x01(\t\x12\x11\n\tdomain_id\x18\" \x01(\t\x12\x12\n\ncreated_at\x18) \x01(\t\x12\x13\n\x0boccurred_at\x18* \x01(\t\"Y\n\nEventsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.monitoring.v1.EventInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Y\n\x0e\x45ventStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa9\x04\n\x05\x45vent\x12\x91\x01\n\x06\x63reate\x12..spaceone.api.monitoring.v1.CreateEventRequest\x1a\x16.google.protobuf.Empty\"?\x82\xd3\xe4\x93\x02\x39\"7/monitoring/v1/webhook/{webhook_id}/{access_key}/events\x12\x82\x01\n\x03get\x12+.spaceone.api.monitoring.v1.GetEventRequest\x1a%.spaceone.api.monitoring.v1.EventInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/monitoring/v1/event/{event_id}\x12\x95\x01\n\x04list\x12&.spaceone.api.monitoring.v1.EventQuery\x1a&.spaceone.api.monitoring.v1.EventsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/monitoring/v1/eventsZ\x1e\"\x1c/monitoring/v1/events/search\x12o\n\x04stat\x12*.spaceone.api.monitoring.v1.EventStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/monitoring/v1/events/statb\x06proto3')



_EVENTRESOURCE = DESCRIPTOR.message_types_by_name['EventResource']
_EVENTACCOUNT = DESCRIPTOR.message_types_by_name['EventAccount']
_CREATEEVENTREQUEST = DESCRIPTOR.message_types_by_name['CreateEventRequest']
_GETEVENTREQUEST = DESCRIPTOR.message_types_by_name['GetEventRequest']
_EVENTQUERY = DESCRIPTOR.message_types_by_name['EventQuery']
_EVENTINFO = DESCRIPTOR.message_types_by_name['EventInfo']
_EVENTSINFO = DESCRIPTOR.message_types_by_name['EventsInfo']
_EVENTSTATQUERY = DESCRIPTOR.message_types_by_name['EventStatQuery']
EventResource = _reflection.GeneratedProtocolMessageType('EventResource', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRESOURCE,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventResource)
  })
_sym_db.RegisterMessage(EventResource)

EventAccount = _reflection.GeneratedProtocolMessageType('EventAccount', (_message.Message,), {
  'DESCRIPTOR' : _EVENTACCOUNT,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventAccount)
  })
_sym_db.RegisterMessage(EventAccount)

CreateEventRequest = _reflection.GeneratedProtocolMessageType('CreateEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateEventRequest)
  })
_sym_db.RegisterMessage(CreateEventRequest)

GetEventRequest = _reflection.GeneratedProtocolMessageType('GetEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetEventRequest)
  })
_sym_db.RegisterMessage(GetEventRequest)

EventQuery = _reflection.GeneratedProtocolMessageType('EventQuery', (_message.Message,), {
  'DESCRIPTOR' : _EVENTQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventQuery)
  })
_sym_db.RegisterMessage(EventQuery)

EventInfo = _reflection.GeneratedProtocolMessageType('EventInfo', (_message.Message,), {
  'DESCRIPTOR' : _EVENTINFO,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventInfo)
  })
_sym_db.RegisterMessage(EventInfo)

EventsInfo = _reflection.GeneratedProtocolMessageType('EventsInfo', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventsInfo)
  })
_sym_db.RegisterMessage(EventsInfo)

EventStatQuery = _reflection.GeneratedProtocolMessageType('EventStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.EventStatQuery)
  })
_sym_db.RegisterMessage(EventStatQuery)

_EVENT = DESCRIPTOR.services_by_name['Event']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EVENT.methods_by_name['create']._options = None
  _EVENT.methods_by_name['create']._serialized_options = b'\202\323\344\223\0029\"7/monitoring/v1/webhook/{webhook_id}/{access_key}/events'
  _EVENT.methods_by_name['get']._options = None
  _EVENT.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/monitoring/v1/event/{event_id}'
  _EVENT.methods_by_name['list']._options = None
  _EVENT.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/monitoring/v1/eventsZ\036\"\034/monitoring/v1/events/search'
  _EVENT.methods_by_name['stat']._options = None
  _EVENT.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/monitoring/v1/events/stat'
  _EVENTRESOURCE._serialized_start=193
  _EVENTRESOURCE._serialized_end=266
  _EVENTACCOUNT._serialized_start=268
  _EVENTACCOUNT._serialized_end=324
  _CREATEEVENTREQUEST._serialized_start=326
  _CREATEEVENTREQUEST._serialized_end=425
  _GETEVENTREQUEST._serialized_start=427
  _GETEVENTREQUEST._serialized_end=495
  _EVENTQUERY._serialized_start=498
  _EVENTQUERY._serialized_end=762
  _EVENTINFO._serialized_start=765
  _EVENTINFO._serialized_end=1269
  _EVENTSINFO._serialized_start=1271
  _EVENTSINFO._serialized_end=1360
  _EVENTSTATQUERY._serialized_start=1362
  _EVENTSTATQUERY._serialized_end=1451
  _EVENT._serialized_start=1454
  _EVENT._serialized_end=2007
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.board.v1 import board_pb2 as spaceone_dot_api_dot_board_dot_v1_dot_board__pb2


class BoardStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.board.v1.Board/create',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.CreateBoardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.board.v1.Board/update',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.UpdateBoardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
                )
        self.set_categories = channel.unary_unary(
                '/spaceone.api.board.v1.Board/set_categories',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.SetBoardCategoriesRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.board.v1.Board/delete',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.board.v1.Board/get',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.GetBoardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.board.v1.Board/list',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.board.v1.Board/stat',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class BoardServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Board with SYSTEM permission. The `name` of the board is only required. You can add one or more `categories` representing the Board's attributes.
        request_example: >-
        {
        "name": "notice",
        "categories": ["admin", "developer", "devops"],
        "tags": {"a": "b"}
        }
        response_example: >-
        {
        "board_id": "board-123456789012",
        "name": "notice",
        "categories": [
        "admin",
        "developer",
        "devops"
        ],
        "tags": {
        "a": "b"
        },
        "created_at": "2022-01-01T06:47:27.759Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Board with SYSTEM permission. You can make changes in Board settings, including `name` and `tags`.
        request_example: >-
        {
        "board_id": "board-123456789012",
        "name": "system notice",
        "tags": {"b": "c"}
        }
        response_example: >-
        {
        "board_id": "board-123456789012",
        "name": "system notice",
        "categories": [
        "admin",
        "developer",
        "devops"
        ],
        "tags": {
        "b": "c"
        },
        "created_at": "2022-01-01T06:47:27.759Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_categories(self, request, context):
        """
        desc: Adds or changes `categories` of a specific Board with SYSTEM permission. A change in `categories` of a Board does not affect the `category` of the child Posts.
        request_example: >-
        {
        "board_id": "board-123456789012",
        "categories": ["Developer", "SRE", "Devops"]
        }
        response_example: >-
        {
        "board_id": "board-123456789012",
        "name": "dev-notice",
        "categories": [
        "Developer",
        "SRE",
        "Devops"
        ],
        "tags": {
        "b": "c"
        },
        "created_at": "2022-01-01T05:24:19.758Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Board with `SYSTEM` permission. You can delete a Board regardless of the presence of Posts created under the Board.
        request_example: >-
        {
        "board_id": "board-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Board. You must specify the `board_id` of the Board to get. Prints detailed information about the Board, including `name`, `categories`.
        request_example: >-
        {
        "board_id": "board-123456789012"
        }
        response_example: >-
        {
        "board_id": "board-123456789012",
        "name": "dev-notice",
        "categories": [
        "Developer",
        "SRE",
        "Devops"
        ],
        "tags": {
        "b": "c"
        },
        "created_at": "2022-01-01T05:24:19.758Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Boards. You can use a query to get a filtered list of Boards.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "board_id": "board-123456789012",
        "name": "dev-notice",
        "categories": [
        "flower",
        "school",
        "spaceone"
        ],
        "tags": {
        "b": "c"
        },
        "created_at": "2022-01-01T05:16:08.549Z"
        },
        {
        "board_id": "board-987654321098",
        "name": "notice",
        "tags": {
        "a": "b"
        },
        "created_at": "2022-01-01T05:24:19.758Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BoardServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.CreateBoardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.UpdateBoardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.SerializeToString,
            ),
            'set_categories': grpc.unary_unary_rpc_method_handler(
                    servicer.set_categories,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.SetBoardCategoriesRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.GetBoardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.board.v1.Board', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Board(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/create',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.CreateBoardRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/update',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.UpdateBoardRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_categories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/set_categories',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.SetBoardCategoriesRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/delete',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/get',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.GetBoardRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/list',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardQuery.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Board/stat',
            spaceone_dot_api_dot_board_dot_v1_dot_board__pb2.BoardStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/notification/v1/notification.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x93\x04\n\x19\x43reateNotificationRequest\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12(\n\x07message\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x63\n\x11notification_type\x18\x05 \x01(\x0e\x32H.spaceone.api.notification.v1.CreateNotificationRequest.NotificationType\x12\x65\n\x12notification_level\x18\x07 \x01(\x0e\x32I.spaceone.api.notification.v1.CreateNotificationRequest.NotificationLEVEL\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\"S\n\x11NotificationLEVEL\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"\xc9\x01\n\x17PushNotificationRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07message\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x19\n\x11notification_type\x18\x04 \x01(\t\x12\x1a\n\x12notification_level\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"?\n\x13NotificationRequest\x12\x15\n\rnotifications\x18\x01 \x03(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x1aSetReadNotificationRequest\x12\x15\n\rnotifications\x18\x01 \x03(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"R\n\x16GetNotificationRequest\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc0\x04\n\x11NotificationQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x17\n\x0fnotification_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12[\n\x11notification_type\x18\x04 \x01(\x0e\x32@.spaceone.api.notification.v1.NotificationQuery.NotificationType\x12]\n\x12notification_level\x18\x05 \x01(\x0e\x32\x41.spaceone.api.notification.v1.NotificationQuery.NotificationLEVEL\x12\x0f\n\x07is_read\x18\x06 \x01(\x08\x12\x1e\n\x16parent_notification_id\x18\x07 \x01(\t\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x0f\n\x07user_id\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\"S\n\x11NotificationLEVEL\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"\x9b\x04\n\x10NotificationInfo\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12(\n\x07message\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Z\n\x11notification_type\x18\x04 \x01(\x0e\x32?.spaceone.api.notification.v1.NotificationInfo.NotificationType\x12\\\n\x12notification_level\x18\x05 \x01(\x0e\x32@.spaceone.api.notification.v1.NotificationInfo.NotificationLEVEL\x12\x0f\n\x07is_read\x18\x06 \x01(\x08\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\"S\n\x11NotificationLEVEL\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03LV1\x10\x02\x12\x07\n\x03LV2\x10\x03\x12\x07\n\x03LV3\x10\x04\x12\x07\n\x03LV4\x10\x05\x12\x07\n\x03LV5\x10\x06\"i\n\x11NotificationsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.notification.v1.NotificationInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15NotificationStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x97\x08\n\x0cNotification\x12\x81\x01\n\x06\x63reate\x12\x37.spaceone.api.notification.v1.CreateNotificationRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1e/notification/v1/notifications\x12\x82\x01\n\x04push\x12\x35.spaceone.api.notification.v1.PushNotificationRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/notifications/push\x12\x8a\x01\n\x06\x64\x65lete\x12\x31.spaceone.api.notification.v1.NotificationRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/*-/notification/v1/notification/{notifications}\x12\x89\x01\n\x08set_read\x12\x38.spaceone.api.notification.v1.SetReadNotificationRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/notifications/read\x12\xa4\x01\n\x03get\x12\x34.spaceone.api.notification.v1.GetNotificationRequest\x1a..spaceone.api.notification.v1.NotificationInfo\"7\x82\xd3\xe4\x93\x02\x31\x12//notification/v1/notification/{notification_id}\x12\xb9\x01\n\x04list\x12/.spaceone.api.notification.v1.NotificationQuery\x1a/.spaceone.api.notification.v1.NotificationsInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/notification/v1/notificationsZ\'\"%/notification/v1/notifications/search\x12\x81\x01\n\x04stat\x12\x33.spaceone.api.notification.v1.NotificationStatQuery\x1a\x17.google.protobuf.Struct\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/notifications/statb\x06proto3')



_CREATENOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['CreateNotificationRequest']
_PUSHNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['PushNotificationRequest']
_NOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['NotificationRequest']
_SETREADNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['SetReadNotificationRequest']
_GETNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['GetNotificationRequest']
_NOTIFICATIONQUERY = DESCRIPTOR.message_types_by_name['NotificationQuery']
_NOTIFICATIONINFO = DESCRIPTOR.message_types_by_name['NotificationInfo']
_NOTIFICATIONSINFO = DESCRIPTOR.message_types_by_name['NotificationsInfo']
_NOTIFICATIONSTATQUERY = DESCRIPTOR.message_types_by_name['NotificationStatQuery']
_CREATENOTIFICATIONREQUEST_NOTIFICATIONTYPE = _CREATENOTIFICATIONREQUEST.enum_types_by_name['NotificationType']
_CREATENOTIFICATIONREQUEST_NOTIFICATIONLEVEL = _CREATENOTIFICATIONREQUEST.enum_types_by_name['NotificationLEVEL']
_NOTIFICATIONQUERY_NOTIFICATIONTYPE = _NOTIFICATIONQUERY.enum_types_by_name['NotificationType']
_NOTIFICATIONQUERY_NOTIFICATIONLEVEL = _NOTIFICATIONQUERY.enum_types_by_name['NotificationLEVEL']
_NOTIFICATIONINFO_NOTIFICATIONTYPE = _NOTIFICATIONINFO.enum_types_by_name['NotificationType']
_NOTIFICATIONINFO_NOTIFICATIONLEVEL = _NOTIFICATIONINFO.enum_types_by_name['NotificationLEVEL']
CreateNotificationRequest = _reflection.GeneratedProtocolMessageType('CreateNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateNotificationRequest)
  })
_sym_db.RegisterMessage(CreateNotificationRequest)

PushNotificationRequest = _reflection.GeneratedProtocolMessageType('PushNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUSHNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.PushNotificationRequest)
  })
_sym_db.RegisterMessage(PushNotificationRequest)

NotificationRequest = _reflection.GeneratedProtocolMessageType('NotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationRequest)
  })
_sym_db.RegisterMessage(NotificationRequest)

SetReadNotificationRequest = _reflection.GeneratedProtocolMessageType('SetReadNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETREADNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.SetReadNotificationRequest)
  })
_sym_db.RegisterMessage(SetReadNotificationRequest)

GetNotificationRequest = _reflection.GeneratedProtocolMessageType('GetNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetNotificationRequest)
  })
_sym_db.RegisterMessage(GetNotificationRequest)

NotificationQuery = _reflection.GeneratedProtocolMessageType('NotificationQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONQUERY,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationQuery)
  })
_sym_db.RegisterMessage(NotificationQuery)

NotificationInfo = _reflection.GeneratedProtocolMessageType('NotificationInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONINFO,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationInfo)
  })
_sym_db.RegisterMessage(NotificationInfo)

NotificationsInfo = _reflection.GeneratedProtocolMessageType('NotificationsInfo', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSINFO,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationsInfo)
  })
_sym_db.RegisterMessage(NotificationsInfo)

NotificationStatQuery = _reflection.GeneratedProtocolMessageType('NotificationStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.NotificationStatQuery)
  })
_sym_db.RegisterMessage(NotificationStatQuery)

_NOTIFICATION = DESCRIPTOR.services_by_name['Notification']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFICATION.methods_by_name['create']._options = None
  _NOTIFICATION.methods_by_name['create']._serialized_options = b'\202\323\344\223\002 \"\036/notification/v1/notifications'
  _NOTIFICATION.methods_by_name['push']._options = None
  _NOTIFICATION.methods_by_name['push']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/notifications/push'
  _NOTIFICATION.methods_by_name['delete']._options = None
  _NOTIFICATION.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002/*-/notification/v1/notification/{notifications}'
  _NOTIFICATION.methods_by_name['set_read']._options = None
  _NOTIFICATION.methods_by_name['set_read']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/notifications/read'
  _NOTIFICATION.methods_by_name['get']._options = None
  _NOTIFICATION.methods_by_name['get']._serialized_options = b'\202\323\344\223\0021\022//notification/v1/notification/{notification_id}'
  _NOTIFICATION.methods_by_name['list']._options = None
  _NOTIFICATION.methods_by_name['list']._serialized_options = b'\202\323\344\223\002I\022\036/notification/v1/notificationsZ\'\"%/notification/v1/notifications/search'
  _NOTIFICATION.methods_by_name['stat']._options = None
  _NOTIFICATION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/notifications/stat'
  _CREATENOTIFICATIONREQUEST._serialized_start=205
  _CREATENOTIFICATIONREQUEST._serialized_end=736
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONTYPE._serialized_start=558
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONTYPE._serialized_end=651
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONLEVEL._serialized_start=653
  _CREATENOTIFICATIONREQUEST_NOTIFICATIONLEVEL._serialized_end=736
  _PUSHNOTIFICATIONREQUEST._serialized_start=739
  _PUSHNOTIFICATIONREQUEST._serialized_end=940
  _NOTIFICATIONREQUEST._serialized_start=942
  _NOTIFICATIONREQUEST._serialized_end=1005
  _SETREADNOTIFICATIONREQUEST._serialized_start=1007
  _SETREADNOTIFICATIONREQUEST._serialized_end=1077
  _GETNOTIFICATIONREQUEST._serialized_start=1079
  _GETNOTIFICATIONREQUEST._serialized_end=1161
  _NOTIFICATIONQUERY._serialized_start=1164
  _NOTIFICATIONQUERY._serialized_end=1740
  _NOTIFICATIONQUERY_NOTIFICATIONTYPE._serialized_start=558
  _NOTIFICATIONQUERY_NOTIFICATIONTYPE._serialized_end=651
  _NOTIFICATIONQUERY_NOTIFICATIONLEVEL._serialized_start=653
  _NOTIFICATIONQUERY_NOTIFICATIONLEVEL._serialized_end=736
  _NOTIFICATIONINFO._serialized_start=1743
  _NOTIFICATIONINFO._serialized_end=2282
  _NOTIFICATIONINFO_NOTIFICATIONTYPE._serialized_start=558
  _NOTIFICATIONINFO_NOTIFICATIONTYPE._serialized_end=651
  _NOTIFICATIONINFO_NOTIFICATIONLEVEL._serialized_start=653
  _NOTIFICATIONINFO_NOTIFICATIONLEVEL._serialized_end=736
  _NOTIFICATIONSINFO._serialized_start=2284
  _NOTIFICATIONSINFO._serialized_end=2389
  _NOTIFICATIONSTATQUERY._serialized_start=2391
  _NOTIFICATIONSTATQUERY._serialized_end=2487
  _NOTIFICATION._serialized_start=2490
  _NOTIFICATION._serialized_end=3537
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/core/v1/handler.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"spaceone/api/core/v1/handler.proto\x12\x14spaceone.api.core.v1\x1a\x1cgoogle/protobuf/struct.proto\"\xc7\x03\n\x14\x41uthorizationRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0c\n\x04verb\x18\x03 \x01(\t\x12?\n\x05scope\x18\x04 \x01(\x0e\x32\x30.spaceone.api.core.v1.AuthorizationRequest.Scope\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x18\n\x10project_group_id\x18\x07 \x01(\t\x12\x0f\n\x07user_id\x18\x08 \x01(\t\x12\x1a\n\x12require_project_id\x18\t \x01(\x08\x12 \n\x18require_project_group_id\x18\n \x01(\x08\x12\x17\n\x0frequire_user_id\x18\x0b \x01(\x08\x12\x19\n\x11require_domain_id\x18\x0c \x01(\x08\"y\n\x05Scope\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\n\n\x06\x44OMAIN\x10\x02\x12\x0b\n\x07PROJECT\x10\x03\x12\x08\n\x04USER\x10\x04\x12\n\n\x06PUBLIC\x10\x05\x12\x14\n\x10PUBLIC_OR_DOMAIN\x10\x06\x12\x15\n\x11\x44OMAIN_OR_PROJECT\x10\x07\"T\n\x15\x41uthorizationResponse\x12\x11\n\trole_type\x18\x01 \x01(\t\x12\x10\n\x08projects\x18\x02 \x03(\t\x12\x16\n\x0eproject_groups\x18\x03 \x03(\t\"*\n\x15\x41uthenticationRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\"?\n\x16\x41uthenticationResponse\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t\"y\n\x0c\x45ventRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0c\n\x04verb\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12(\n\x07message\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Structb\x06proto3')



_AUTHORIZATIONREQUEST = DESCRIPTOR.message_types_by_name['AuthorizationRequest']
_AUTHORIZATIONRESPONSE = DESCRIPTOR.message_types_by_name['AuthorizationResponse']
_AUTHENTICATIONREQUEST = DESCRIPTOR.message_types_by_name['AuthenticationRequest']
_AUTHENTICATIONRESPONSE = DESCRIPTOR.message_types_by_name['AuthenticationResponse']
_EVENTREQUEST = DESCRIPTOR.message_types_by_name['EventRequest']
_AUTHORIZATIONREQUEST_SCOPE = _AUTHORIZATIONREQUEST.enum_types_by_name['Scope']
AuthorizationRequest = _reflection.GeneratedProtocolMessageType('AuthorizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONREQUEST,
  '__module__' : 'spaceone.api.core.v1.handler_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AuthorizationRequest)
  })
_sym_db.RegisterMessage(AuthorizationRequest)

AuthorizationResponse = _reflection.GeneratedProtocolMessageType('AuthorizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONRESPONSE,
  '__module__' : 'spaceone.api.core.v1.handler_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AuthorizationResponse)
  })
_sym_db.RegisterMessage(AuthorizationResponse)

AuthenticationRequest = _reflection.GeneratedProtocolMessageType('AuthenticationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONREQUEST,
  '__module__' : 'spaceone.api.core.v1.handler_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AuthenticationRequest)
  })
_sym_db.RegisterMessage(AuthenticationRequest)

AuthenticationResponse = _reflection.GeneratedProtocolMessageType('AuthenticationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATIONRESPONSE,
  '__module__' : 'spaceone.api.core.v1.handler_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AuthenticationResponse)
  })
_sym_db.RegisterMessage(AuthenticationResponse)

EventRequest = _reflection.GeneratedProtocolMessageType('EventRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTREQUEST,
  '__module__' : 'spaceone.api.core.v1.handler_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.EventRequest)
  })
_sym_db.RegisterMessage(EventRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUTHORIZATIONREQUEST._serialized_start=91
  _AUTHORIZATIONREQUEST._serialized_end=546
  _AUTHORIZATIONREQUEST_SCOPE._serialized_start=425
  _AUTHORIZATIONREQUEST_SCOPE._serialized_end=546
  _AUTHORIZATIONRESPONSE._serialized_start=548
  _AUTHORIZATIONRESPONSE._serialized_end=632
  _AUTHENTICATIONREQUEST._serialized_start=634
  _AUTHENTICATIONREQUEST._serialized_end=676
  _AUTHENTICATIONRESPONSE._serialized_start=678
  _AUTHENTICATIONRESPONSE._serialized_end=741
  _EVENTREQUEST._serialized_start=743
  _EVENTREQUEST._serialized_end=864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/secret/v1/secret.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spaceone/api/secret/v1/secret.proto\x12\x16spaceone.api.secret.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x98\x02\n\x13\x43reateSecretRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x37\n\x0bsecret_type\x18\x03 \x01(\x0e\x32\".spaceone.api.secret.v1.SecretType\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12\x1a\n\x12service_account_id\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x19\n\x11trusted_secret_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\x9d\x01\n\x13UpdateSecretRequest\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x17\n\x0frelease_project\x18\x06 \x01(\x08\"5\n\rSecretRequest\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"v\n\x17UpdateSecretDataRequest\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\t\"F\n\x10GetSecretRequest\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xff\x01\n\x0bSecretQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\x0bsecret_type\x18\x04 \x01(\x0e\x32\".spaceone.api.secret.v1.SecretType\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x19\n\x11trusted_secret_id\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"|\n\x0eSecretDataInfo\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tencrypted\x18\x02 \x01(\x08\x12\x30\n\x0f\x65ncrypt_options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa1\x02\n\nSecretInfo\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\x0bsecret_type\x18\x03 \x01(\x0e\x32\".spaceone.api.secret.v1.SecretType\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x19\n\x11trusted_secret_id\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"W\n\x0bSecretsInfo\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".spaceone.api.secret.v1.SecretInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0fSecretStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*\'\n\nSecretType\x12\x08\n\x04NONE\x10\x00\x12\x0f\n\x0b\x43REDENTIALS\x10\x01\x32\xf2\x07\n\x06Secret\x12u\n\x06\x63reate\x12+.spaceone.api.secret.v1.CreateSecretRequest\x1a\".spaceone.api.secret.v1.SecretInfo\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x12/secret/v1/secrets\x12\x80\x01\n\x06update\x12+.spaceone.api.secret.v1.UpdateSecretRequest\x1a\".spaceone.api.secret.v1.SecretInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/secret/v1/secret/{secret_id}\x12n\n\x06\x64\x65lete\x12%.spaceone.api.secret.v1.SecretRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/secret/v1/secret/{secret_id}\x12\x82\x01\n\x0bupdate_data\x12/.spaceone.api.secret.v1.UpdateSecretDataRequest\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02$\x1a\"/secret/v1/secret/{secret_id}/data\x12\x85\x01\n\x08get_data\x12%.spaceone.api.secret.v1.SecretRequest\x1a&.spaceone.api.secret.v1.SecretDataInfo\"*\x82\xd3\xe4\x93\x02$\x12\"/secret/v1/secret/{secret_id}/data\x12z\n\x03get\x12(.spaceone.api.secret.v1.GetSecretRequest\x1a\".spaceone.api.secret.v1.SecretInfo\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/secret/v1/secret/{secret_id}\x12\x89\x01\n\x04list\x12#.spaceone.api.secret.v1.SecretQuery\x1a#.spaceone.api.secret.v1.SecretsInfo\"7\x82\xd3\xe4\x93\x02\x31\x12\x12/secret/v1/secretsZ\x1b\"\x19/secret/v1/secrets/search\x12i\n\x04stat\x12\'.spaceone.api.secret.v1.SecretStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/secret/v1/secrets/statb\x06proto3')

_SECRETTYPE = DESCRIPTOR.enum_types_by_name['SecretType']
SecretType = enum_type_wrapper.EnumTypeWrapper(_SECRETTYPE)
NONE = 0
CREDENTIALS = 1


_CREATESECRETREQUEST = DESCRIPTOR.message_types_by_name['CreateSecretRequest']
_UPDATESECRETREQUEST = DESCRIPTOR.message_types_by_name['UpdateSecretRequest']
_SECRETREQUEST = DESCRIPTOR.message_types_by_name['SecretRequest']
_UPDATESECRETDATAREQUEST = DESCRIPTOR.message_types_by_name['UpdateSecretDataRequest']
_GETSECRETREQUEST = DESCRIPTOR.message_types_by_name['GetSecretRequest']
_SECRETQUERY = DESCRIPTOR.message_types_by_name['SecretQuery']
_SECRETDATAINFO = DESCRIPTOR.message_types_by_name['SecretDataInfo']
_SECRETINFO = DESCRIPTOR.message_types_by_name['SecretInfo']
_SECRETSINFO = DESCRIPTOR.message_types_by_name['SecretsInfo']
_SECRETSTATQUERY = DESCRIPTOR.message_types_by_name['SecretStatQuery']
CreateSecretRequest = _reflection.GeneratedProtocolMessageType('CreateSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.CreateSecretRequest)
  })
_sym_db.RegisterMessage(CreateSecretRequest)

UpdateSecretRequest = _reflection.GeneratedProtocolMessageType('UpdateSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateSecretRequest)
  })
_sym_db.RegisterMessage(UpdateSecretRequest)

SecretRequest = _reflection.GeneratedProtocolMessageType('SecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretRequest)
  })
_sym_db.RegisterMessage(SecretRequest)

UpdateSecretDataRequest = _reflection.GeneratedProtocolMessageType('UpdateSecretDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESECRETDATAREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateSecretDataRequest)
  })
_sym_db.RegisterMessage(UpdateSecretDataRequest)

GetSecretRequest = _reflection.GeneratedProtocolMessageType('GetSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.GetSecretRequest)
  })
_sym_db.RegisterMessage(GetSecretRequest)

SecretQuery = _reflection.GeneratedProtocolMessageType('SecretQuery', (_message.Message,), {
  'DESCRIPTOR' : _SECRETQUERY,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretQuery)
  })
_sym_db.RegisterMessage(SecretQuery)

SecretDataInfo = _reflection.GeneratedProtocolMessageType('SecretDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETDATAINFO,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretDataInfo)
  })
_sym_db.RegisterMessage(SecretDataInfo)

SecretInfo = _reflection.GeneratedProtocolMessageType('SecretInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETINFO,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretInfo)
  })
_sym_db.RegisterMessage(SecretInfo)

SecretsInfo = _reflection.GeneratedProtocolMessageType('SecretsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSINFO,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretsInfo)
  })
_sym_db.RegisterMessage(SecretsInfo)

SecretStatQuery = _reflection.GeneratedProtocolMessageType('SecretStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTATQUERY,
  '__module__' : 'spaceone.api.secret.v1.secret_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretStatQuery)
  })
_sym_db.RegisterMessage(SecretStatQuery)

_SECRET = DESCRIPTOR.services_by_name['Secret']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SECRET.methods_by_name['create']._options = None
  _SECRET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\024\"\022/secret/v1/secrets'
  _SECRET.methods_by_name['update']._options = None
  _SECRET.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\037\032\035/secret/v1/secret/{secret_id}'
  _SECRET.methods_by_name['delete']._options = None
  _SECRET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\037*\035/secret/v1/secret/{secret_id}'
  _SECRET.methods_by_name['update_data']._options = None
  _SECRET.methods_by_name['update_data']._serialized_options = b'\202\323\344\223\002$\032\"/secret/v1/secret/{secret_id}/data'
  _SECRET.methods_by_name['get_data']._options = None
  _SECRET.methods_by_name['get_data']._serialized_options = b'\202\323\344\223\002$\022\"/secret/v1/secret/{secret_id}/data'
  _SECRET.methods_by_name['get']._options = None
  _SECRET.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\037\022\035/secret/v1/secret/{secret_id}'
  _SECRET.methods_by_name['list']._options = None
  _SECRET.methods_by_name['list']._serialized_options = b'\202\323\344\223\0021\022\022/secret/v1/secretsZ\033\"\031/secret/v1/secrets/search'
  _SECRET.methods_by_name['stat']._options = None
  _SECRET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/secret/v1/secrets/stat'
  _SECRETTYPE._serialized_start=1733
  _SECRETTYPE._serialized_end=1772
  _CREATESECRETREQUEST._serialized_start=187
  _CREATESECRETREQUEST._serialized_end=467
  _UPDATESECRETREQUEST._serialized_start=470
  _UPDATESECRETREQUEST._serialized_end=627
  _SECRETREQUEST._serialized_start=629
  _SECRETREQUEST._serialized_end=682
  _UPDATESECRETDATAREQUEST._serialized_start=684
  _UPDATESECRETDATAREQUEST._serialized_end=802
  _GETSECRETREQUEST._serialized_start=804
  _GETSECRETREQUEST._serialized_end=874
  _SECRETQUERY._serialized_start=877
  _SECRETQUERY._serialized_end=1132
  _SECRETDATAINFO._serialized_start=1134
  _SECRETDATAINFO._serialized_end=1258
  _SECRETINFO._serialized_start=1261
  _SECRETINFO._serialized_end=1550
  _SECRETSINFO._serialized_start=1552
  _SECRETSINFO._serialized_end=1639
  _SECRETSTATQUERY._serialized_start=1641
  _SECRETSTATQUERY._serialized_end=1731
  _SECRET._serialized_start=1775
  _SECRET._serialized_end=2785
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/budget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/cost_analysis/v1/budget.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"+\n\x0cPlannedLimit\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x02\"\xe3\x02\n\x12\x42udgetNotification\x12\x11\n\tthreshold\x18\x01 \x01(\x02\x12\x44\n\x04unit\x18\x02 \x01(\x0e\x32\x36.spaceone.api.cost_analysis.v1.BudgetNotification.Unit\x12]\n\x11notification_type\x18\x03 \x01(\x0e\x32\x42.spaceone.api.cost_analysis.v1.BudgetNotification.NotificationType\x12\x15\n\rused_channels\x18\x04 \x03(\t\"3\n\x04Unit\x12\r\n\tUNIT_NONE\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\x12\x0f\n\x0b\x41\x43TUAL_COST\x10\x02\"I\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x0b\n\x07WARNING\x10\x02\"\x95\x04\n\x13\x43reateBudgetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x02\x12\x43\n\x0eplanned_limits\x18\x03 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.PlannedLimit\x12+\n\ncost_types\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12N\n\ttime_unit\x18\x05 \x01(\x0e\x32;.spaceone.api.cost_analysis.v1.CreateBudgetRequest.TimeUnit\x12\r\n\x05start\x18\x06 \x01(\t\x12\x0b\n\x03\x65nd\x18\x07 \x01(\t\x12H\n\rnotifications\x18\x08 \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.BudgetNotification\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x18\n\x10project_group_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"Q\n\x08TimeUnit\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOTAL\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x12\x17\n\x13\x43ONSISTENCY_MONTHLY\x10\x04\"\xd1\x01\n\x13UpdateBudgetRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x02\x12\x43\n\x0eplanned_limits\x18\x04 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.PlannedLimit\x12\x0b\n\x03\x65nd\x18\x05 \x01(\t\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x8e\x01\n\x1cSetBudgetNotificationRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12H\n\rnotifications\x18\x02 \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.BudgetNotification\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"5\n\rBudgetRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x10GetBudgetRequest\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb6\x02\n\x0b\x42udgetQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tbudget_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x18\n\x10project_group_id\x18\x05 \x01(\t\x12\x46\n\ttime_unit\x18\x06 \x01(\x0e\x32\x33.spaceone.api.cost_analysis.v1.BudgetQuery.TimeUnit\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"Q\n\x08TimeUnit\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOTAL\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x12\x17\n\x13\x43ONSISTENCY_MONTHLY\x10\x04\"\xdc\x04\n\nBudgetInfo\x12\x11\n\tbudget_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x02\x12\x43\n\x0eplanned_limits\x18\x04 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.PlannedLimit\x12\x1c\n\x14total_usage_usd_cost\x18\x05 \x01(\x02\x12+\n\ncost_types\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\ttime_unit\x18\x07 \x01(\x0e\x32\x32.spaceone.api.cost_analysis.v1.BudgetInfo.TimeUnit\x12\r\n\x05start\x18\x08 \x01(\t\x12\x0b\n\x03\x65nd\x18\t \x01(\t\x12H\n\rnotifications\x18\n \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.BudgetNotification\x12%\n\x04tags\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x1f \x01(\t\x12\x18\n\x10project_group_id\x18  \x01(\t\x12\x11\n\tdomain_id\x18! \x01(\t\x12\x12\n\ncreated_at\x18) \x01(\t\x12\x12\n\nupdated_at\x18* \x01(\t\"Q\n\x08TimeUnit\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05TOTAL\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x12\x17\n\x13\x43ONSISTENCY_MONTHLY\x10\x04\"^\n\x0b\x42udgetsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.cost_analysis.v1.BudgetInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0f\x42udgetStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x96\x08\n\x06\x42udget\x12\x8a\x01\n\x06\x63reate\x12\x32.spaceone.api.cost_analysis.v1.CreateBudgetRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/cost-analysis/v1/budgets\x12\x95\x01\n\x06update\x12\x32.spaceone.api.cost_analysis.v1.UpdateBudgetRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\",\x82\xd3\xe4\x93\x02&\x1a$/cost-analysis/v1/budget/{budget_id}\x12\xb5\x01\n\x10set_notification\x12;.spaceone.api.cost_analysis.v1.SetBudgetNotificationRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/cost-analysis/v1/budget/{budget_id}/notification\x12|\n\x06\x64\x65lete\x12,.spaceone.api.cost_analysis.v1.BudgetRequest\x1a\x16.google.protobuf.Empty\",\x82\xd3\xe4\x93\x02&*$/cost-analysis/v1/budget/{budget_id}\x12\x8f\x01\n\x03get\x12/.spaceone.api.cost_analysis.v1.GetBudgetRequest\x1a).spaceone.api.cost_analysis.v1.BudgetInfo\",\x82\xd3\xe4\x93\x02&\x12$/cost-analysis/v1/budget/{budget_id}\x12\xa5\x01\n\x04list\x12*.spaceone.api.cost_analysis.v1.BudgetQuery\x1a*.spaceone.api.cost_analysis.v1.BudgetsInfo\"E\x82\xd3\xe4\x93\x02?\x12\x19/cost-analysis/v1/budgetsZ\"\" /cost-analysis/v1/budgets/search\x12w\n\x04stat\x12..spaceone.api.cost_analysis.v1.BudgetStatQuery\x1a\x17.google.protobuf.Struct\"&\x82\xd3\xe4\x93\x02 \"\x1e/cost-analysis/v1/budgets/statb\x06proto3')



_PLANNEDLIMIT = DESCRIPTOR.message_types_by_name['PlannedLimit']
_BUDGETNOTIFICATION = DESCRIPTOR.message_types_by_name['BudgetNotification']
_CREATEBUDGETREQUEST = DESCRIPTOR.message_types_by_name['CreateBudgetRequest']
_UPDATEBUDGETREQUEST = DESCRIPTOR.message_types_by_name['UpdateBudgetRequest']
_SETBUDGETNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['SetBudgetNotificationRequest']
_BUDGETREQUEST = DESCRIPTOR.message_types_by_name['BudgetRequest']
_GETBUDGETREQUEST = DESCRIPTOR.message_types_by_name['GetBudgetRequest']
_BUDGETQUERY = DESCRIPTOR.message_types_by_name['BudgetQuery']
_BUDGETINFO = DESCRIPTOR.message_types_by_name['BudgetInfo']
_BUDGETSINFO = DESCRIPTOR.message_types_by_name['BudgetsInfo']
_BUDGETSTATQUERY = DESCRIPTOR.message_types_by_name['BudgetStatQuery']
_BUDGETNOTIFICATION_UNIT = _BUDGETNOTIFICATION.enum_types_by_name['Unit']
_BUDGETNOTIFICATION_NOTIFICATIONTYPE = _BUDGETNOTIFICATION.enum_types_by_name['NotificationType']
_CREATEBUDGETREQUEST_TIMEUNIT = _CREATEBUDGETREQUEST.enum_types_by_name['TimeUnit']
_BUDGETQUERY_TIMEUNIT = _BUDGETQUERY.enum_types_by_name['TimeUnit']
_BUDGETINFO_TIMEUNIT = _BUDGETINFO.enum_types_by_name['TimeUnit']
PlannedLimit = _reflection.GeneratedProtocolMessageType('PlannedLimit', (_message.Message,), {
  'DESCRIPTOR' : _PLANNEDLIMIT,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PlannedLimit)
  })
_sym_db.RegisterMessage(PlannedLimit)

BudgetNotification = _reflection.GeneratedProtocolMessageType('BudgetNotification', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETNOTIFICATION,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetNotification)
  })
_sym_db.RegisterMessage(BudgetNotification)

CreateBudgetRequest = _reflection.GeneratedProtocolMessageType('CreateBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateBudgetRequest)
  })
_sym_db.RegisterMessage(CreateBudgetRequest)

UpdateBudgetRequest = _reflection.GeneratedProtocolMessageType('UpdateBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateBudgetRequest)
  })
_sym_db.RegisterMessage(UpdateBudgetRequest)

SetBudgetNotificationRequest = _reflection.GeneratedProtocolMessageType('SetBudgetNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETBUDGETNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SetBudgetNotificationRequest)
  })
_sym_db.RegisterMessage(SetBudgetNotificationRequest)

BudgetRequest = _reflection.GeneratedProtocolMessageType('BudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetRequest)
  })
_sym_db.RegisterMessage(BudgetRequest)

GetBudgetRequest = _reflection.GeneratedProtocolMessageType('GetBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUDGETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetBudgetRequest)
  })
_sym_db.RegisterMessage(GetBudgetRequest)

BudgetQuery = _reflection.GeneratedProtocolMessageType('BudgetQuery', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetQuery)
  })
_sym_db.RegisterMessage(BudgetQuery)

BudgetInfo = _reflection.GeneratedProtocolMessageType('BudgetInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetInfo)
  })
_sym_db.RegisterMessage(BudgetInfo)

BudgetsInfo = _reflection.GeneratedProtocolMessageType('BudgetsInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetsInfo)
  })
_sym_db.RegisterMessage(BudgetsInfo)

BudgetStatQuery = _reflection.GeneratedProtocolMessageType('BudgetStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _BUDGETSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.budget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.BudgetStatQuery)
  })
_sym_db.RegisterMessage(BudgetStatQuery)

_BUDGET = DESCRIPTOR.services_by_name['Budget']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUDGET.methods_by_name['create']._options = None
  _BUDGET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\033\"\031/cost-analysis/v1/budgets'
  _BUDGET.methods_by_name['update']._options = None
  _BUDGET.methods_by_name['update']._serialized_options = b'\202\323\344\223\002&\032$/cost-analysis/v1/budget/{budget_id}'
  _BUDGET.methods_by_name['set_notification']._options = None
  _BUDGET.methods_by_name['set_notification']._serialized_options = b'\202\323\344\223\0023\0321/cost-analysis/v1/budget/{budget_id}/notification'
  _BUDGET.methods_by_name['delete']._options = None
  _BUDGET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002&*$/cost-analysis/v1/budget/{budget_id}'
  _BUDGET.methods_by_name['get']._options = None
  _BUDGET.methods_by_name['get']._serialized_options = b'\202\323\344\223\002&\022$/cost-analysis/v1/budget/{budget_id}'
  _BUDGET.methods_by_name['list']._options = None
  _BUDGET.methods_by_name['list']._serialized_options = b'\202\323\344\223\002?\022\031/cost-analysis/v1/budgetsZ\"\" /cost-analysis/v1/budgets/search'
  _BUDGET.methods_by_name['stat']._options = None
  _BUDGET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002 \"\036/cost-analysis/v1/budgets/stat'
  _PLANNEDLIMIT._serialized_start=200
  _PLANNEDLIMIT._serialized_end=243
  _BUDGETNOTIFICATION._serialized_start=246
  _BUDGETNOTIFICATION._serialized_end=601
  _BUDGETNOTIFICATION_UNIT._serialized_start=475
  _BUDGETNOTIFICATION_UNIT._serialized_end=526
  _BUDGETNOTIFICATION_NOTIFICATIONTYPE._serialized_start=528
  _BUDGETNOTIFICATION_NOTIFICATIONTYPE._serialized_end=601
  _CREATEBUDGETREQUEST._serialized_start=604
  _CREATEBUDGETREQUEST._serialized_end=1137
  _CREATEBUDGETREQUEST_TIMEUNIT._serialized_start=1056
  _CREATEBUDGETREQUEST_TIMEUNIT._serialized_end=1137
  _UPDATEBUDGETREQUEST._serialized_start=1140
  _UPDATEBUDGETREQUEST._serialized_end=1349
  _SETBUDGETNOTIFICATIONREQUEST._serialized_start=1352
  _SETBUDGETNOTIFICATIONREQUEST._serialized_end=1494
  _BUDGETREQUEST._serialized_start=1496
  _BUDGETREQUEST._serialized_end=1549
  _GETBUDGETREQUEST._serialized_start=1551
  _GETBUDGETREQUEST._serialized_end=1621
  _BUDGETQUERY._serialized_start=1624
  _BUDGETQUERY._serialized_end=1934
  _BUDGETQUERY_TIMEUNIT._serialized_start=1056
  _BUDGETQUERY_TIMEUNIT._serialized_end=1137
  _BUDGETINFO._serialized_start=1937
  _BUDGETINFO._serialized_end=2541
  _BUDGETINFO_TIMEUNIT._serialized_start=1056
  _BUDGETINFO_TIMEUNIT._serialized_end=1137
  _BUDGETSINFO._serialized_start=2543
  _BUDGETSINFO._serialized_end=2637
  _BUDGETSTATQUERY._serialized_start=2639
  _BUDGETSTATQUERY._serialized_end=2729
  _BUDGET._serialized_start=2732
  _BUDGET._serialized_end=3778
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/plugin/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/notification/plugin/protocol.proto\x12 spaceone.api.notification.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"7\n\x0bInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"m\n\x13PluginVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\nPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xcc\x01\n\x08Protocol\x12\x65\n\x04init\x12-.spaceone.api.notification.plugin.InitRequest\x1a,.spaceone.api.notification.plugin.PluginInfo\"\x00\x12Y\n\x06verify\x12\x35.spaceone.api.notification.plugin.PluginVerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_INITREQUEST = DESCRIPTOR.message_types_by_name['InitRequest']
_PLUGINVERIFYREQUEST = DESCRIPTOR.message_types_by_name['PluginVerifyRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'spaceone.api.notification.plugin.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

PluginVerifyRequest = _reflection.GeneratedProtocolMessageType('PluginVerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINVERIFYREQUEST,
  '__module__' : 'spaceone.api.notification.plugin.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.PluginVerifyRequest)
  })
_sym_db.RegisterMessage(PluginVerifyRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.notification.plugin.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_PROTOCOL = DESCRIPTOR.services_by_name['Protocol']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INITREQUEST._serialized_start=144
  _INITREQUEST._serialized_end=199
  _PLUGINVERIFYREQUEST._serialized_start=201
  _PLUGINVERIFYREQUEST._serialized_end=310
  _PLUGININFO._serialized_start=312
  _PLUGININFO._serialized_end=367
  _PROTOCOL._serialized_start=370
  _PROTOCOL._serialized_end=574
# @@protoc_insertion_point(module_scope)
